@@ -1,6 +1,4 @@
-"""
-A setup script to demonstrate build using pycountry
-"""
+"""A setup script to demonstrate build using pycountry."""
 
 from __future__ import annotations
 
