@@ -1,6 +1,5 @@
-"""
-A setup script to demonstrate build using zoneinfo/tzdata
-This version requires the zoneinfo in the zip file
+"""A setup script to demonstrate build using zoneinfo/tzdata
+This version requires the zoneinfo in the zip file.
 """
 
 from __future__ import annotations
